@@ -1,5 +1,11 @@
 //! Project changelog
 
+/// Release 0.4.1
+///
+/// * Asynchronous socket support has been fixed to register interest with the runtime. In absence
+/// of this fix it was possible for an application to busy loop waiting for changes.
+pub mod r0_4_1 {}
+
 /// Release 0.4.0
 ///
 /// * tokio 0.2 and tokio 0.3 support has been replaced by support for tokio 1.0.
